<?php
/* $Id: swedish-iso-8859-1.inc.php,v 2.78.2.2 2005/06/30 19:49:02 lem9 Exp $ */

/*
 * Translated by Bjrn T. Hallberg <bjornth at users.sourceforge.net>
 */

$charset = 'iso-8859-1';
$text_dir = 'ltr';
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = ' ';
$number_decimal_separator = ',';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('bytes', 'kB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Sn', 'Mn', 'Tis', 'Ons', 'Tors', 'Fre', 'Lr');
$month = array('januari', 'februari', 'mars', 'april', 'maj', 'juni', 'juli', 'augusti', 'september', 'oktober', 'november', 'december');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d %B %Y kl %H:%M';
$timespanfmt = '%s dagar, %s timmar, %s minuter och %s sekunder';

$strAPrimaryKey = 'En primr nyckel har lagts till fr %s';
$strAbortedClients = 'Avbrutna';
$strAbsolutePathToDocSqlDir = 'Ange absolut skvg p webbservern till docSQL-katalog';
$strAccessDenied = 'tkomst nekad';
$strAccessDeniedExplanation = 'phpMyAdmin frskte skapa en frbindelse till MySQL-servern, men servern nekade uppkopplingen. Kontrollera vrd, anvndarnamn och lsenord i config.inc.php och frvissa dig om att de stmmer verens med informationen frn administratren av MySQL-servern.';
$strAction = 'tgrd';
$strAddAutoIncrement = 'Lgg till AUTO_INCREMENT-vrde';
$strAddConstraints = 'Lgg till restriktioner';
$strAddDeleteColumn = 'Lgg till/ta bort fltkolumner';
$strAddDeleteRow = 'Lgg till/ta bort villkorsrader';
$strAddDropDatabase = 'Lgg till DROP DATABASE';
$strAddFields = 'Lgg till %s flt';
$strAddHeaderComment = 'Lgg till egen kommentar i huvud (\\n delar rader)';
$strAddIfNotExists = 'Lgg till IF NOT EXISTS';
$strAddIntoComments = 'Lgg till i kommentarer';
$strAddNewField = 'Lgg till flt';
$strAddPrivilegesOnDb = 'Lgg till privilegier till fljande databas';
$strAddPrivilegesOnTbl = 'Lgg till privilegier till fljande tabell';
$strAddSearchConditions = 'Lgg till skvillkor (uttryck i "where"-sats):';
$strAddToIndex = 'Lgg till&nbsp;%s&nbsp;kolumn(er) till index';
$strAddUser = 'Lgg till ny anvndare';
$strAddUserMessage = 'Du har lagt till en ny anvndare.';
$strAddedColumnComment = 'La till kommentar fr kolumn';
$strAddedColumnRelation = 'La till relation fr kolumn';
$strAdministration = 'Administration';
$strAffectedRows = 'Pverkade rader:';
$strAfter = 'Efter %s';
$strAfterInsertBack = 'G tillbaka till fregende sida';
$strAfterInsertNewInsert = 'Lgg till ytterligare en ny rad';
$strAfterInsertNext = 'ndra nsta rad';
$strAfterInsertSame = 'G tillbaka till denna sida';
$strAll = 'Alla';
$strAllTableSameWidth = 'Visa alla tabeller med samma bredd';
$strAlterOrderBy = 'Sortera om tabellen efter';
$strAnIndex = 'Ett index har lagts till fr %s';
$strAnalyzeTable = 'Analysera tabell';
$strAnd = 'Och';
$strAny = 'Vem som helst';
$strAnyHost = 'Vilken vrd som helst';
$strAnyUser = 'Vilken anvndare som helst';
$strApproximateCount = 'Kan vara ungefrligt. Se FAQ 3.11';
$strArabic = 'Arabisk';
$strArmenian = 'Armenisk';
$strAscending = 'Stigande';
$strAtBeginningOfTable = 'I brjan av tabellen';
$strAtEndOfTable = 'I slutet av tabellen';
$strAttr = 'Attribut';
$strAutodetect = 'Autodetektera';
$strAutomaticLayout = 'Automatisk layout';

$strBack = 'Bakt';
$strBaltic = 'Baltisk';
$strBeginCut = 'START URKLIPP';
$strBeginRaw = 'START RTEXT';
$strBinLogEventType = 'Typ av hndelse';
$strBinLogInfo = 'Information';
$strBinLogName = 'Loggnamn';
$strBinLogOriginalPosition = 'Ursprunglig position';
$strBinLogPosition = 'Position';
$strBinLogServerId = 'Server-ID';
$strBinary = 'Binr';
$strBinaryDoNotEdit = 'Binr - ndra inte';
$strBinaryLog = 'Binr logg';
$strBookmarkAllUsers = 'Lt varje anvndare f tillgng till detta bokmrke';
$strBookmarkDeleted = 'Bokmrket har tagits bort.';
$strBookmarkLabel = 'Etikett';
$strBookmarkOptions = 'Bokmrkesalternativ';
$strBookmarkQuery = 'Bokmrkt SQL-frga';
$strBookmarkThis = 'Skapa bokmrke fr den hr SQL-frgan';
$strBookmarkView = 'Visa endast';
$strBrowse = 'Visa';
$strBrowseForeignValues = 'Visa frmmande vrden';
$strBufferPool = 'Buffertutrymme';
$strBufferPoolActivity = 'Buffertaktivitet';
$strBufferPoolUsage = 'Buffertanvndning';
$strBufferReadMisses = 'Lsmissar';
$strBufferReadMissesInPercent = 'Lsmissar i %';
$strBufferWriteWaits = 'Skrivvntanden';
$strBufferWriteWaitsInPercent = 'Skrivvntanden i %';
$strBulgarian = 'Bulgarisk';
$strBusyPages = 'Upptagna sidor';
$strBzError = 'phpMyAdmin kunde inte komprimera SQL-satserna p grund av ett trasigt Bz2-tillgg i denna PHP-version. Det rekommenderas starkt att stta direktivet <code>$cfg[\'BZipDump\']</code> i din phpMyAdmin-konfigurationsfil till <code>FALSE</code>. Om du vill anvnda Bz2-komprimering, br du uppgradera till en senare PHP-version. Se PHP:s buggrapport %s fr detaljer.';
$strBzip = '"bzippad"';

$strCSVOptions = 'CSV-alternativ';
$strCalendar = 'Kalender';
$strCannotLogin = 'Kan ej logga in p MySQL-server';
$strCantLoad = 'kan inte ladda %s-tillgg,<br />var god kontrollera PHP-konfigurationen.';
$strCantLoadRecodeIconv = 'Kan inte ladda tillggen iconv eller recode som behvs fr teckenuppsttningsomvandling. Antingen konfigurera PHP fr att tillta dessa tillgg eller stng av teckenuppsttningsomvandling i phpMyAdmin.';
$strCantRenameIdxToPrimary = 'Kan inte byta namn p index till "PRIMARY"!';
$strCantUseRecodeIconv = 'Kan inte anvnda varken funktionen iconv, libiconv eller recode_string, fastn de ndvndiga tillggen verkar vara laddade. Kontrollera din PHP-konfiguration.';
$strCardinality = 'Kardinalitet';
$strCarriage = 'Vagnretur: \\r';
$strCaseInsensitive = 'skiftlgesoknsligt';
$strCaseSensitive = 'skiftlgesknsligt';
$strCentralEuropean = 'Centraleuropeisk';
$strChange = 'ndra';
$strChangeCopyMode = 'Skapa en ny anvndare med samma privilegier och ...';
$strChangeCopyModeCopy = '... behll den gamla.';
$strChangeCopyModeDeleteAndReload = ' ... ta bort den gamla frn anvndartabellerna och ladda om privilegierna eftert.';
$strChangeCopyModeJustDelete = ' ... ta bort den gamla frn anvndartabellerna.';
$strChangeCopyModeRevoke = ' ... upphv alla aktiva privilegier frn dan gamla och ta bort den eftert.';
$strChangeCopyUser = 'ndra inloggningsinformation / Kopiera anvndare';
$strChangeDisplay = 'Vlj flt som ska visas';
$strChangePassword = 'Byt lsenord';
$strCharset = 'Teckenuppsttning';
$strCharsetOfFile = 'Filens teckenuppsttning:';
$strCharsets = 'Teckenuppsttningar';
$strCharsetsAndCollations = 'Teckenuppsttningar och kollationeringar';
$strCheckAll = 'Markera alla';
$strCheckOverhead = 'Markera ooptimerade';
$strCheckPrivs = 'Kontrollera privilegier';
$strCheckPrivsLong = 'Kontrollera privilegier fr databas &quot;%s&quot;.';
$strCheckTable = 'Kontrollera tabell';
$strChoosePage = 'Vlj en sida att redigera';
$strColComFeat = 'Visning av kolumnkommentarer';
$strCollation = 'Kollationering';
$strColumnNames = 'Kolumn-namn';
$strColumnPrivileges = 'Kolumnspecifika privilegier';
$strCommand = 'Kommando';
$strComments = 'Kommentarer';
$strCommentsForTable = 'KOMMENTARER FR TABELL';
$strCompatibleHashing = 'Kompatibel med MySQL&nbsp;4.0';
$strCompleteInserts = 'Kompletta infogningar';
$strCompression = 'Komprimering';
$strConfigFileError = 'phpMyAdmin kunde inte lsa din konfigurationsfil!<br />Detta kan intrffa om PHP hittar ett fel i den eller om PHP inte hittar filen.<br />Anropa konfigurationsfilen direkt mha lnken nedan och ls PHP:s felmeddelande(n) som du erhller. I de flesta fall saknas ett citationstecken eller ett semikolon ngonstans.<br />Om du erhller en tom sida r allt bra.';
$strConfigureTableCoord = 'Var god ange koordinaterna fr tabellen %s';
$strConnectionError = 'Kan ej skapa frbindelse: ogiltiga instllningar.';
$strConnections = 'Uppkopplingar';
$strConstraintsForDumped = 'Restriktioner fr dumpade tabeller';
$strConstraintsForTable = 'Restriktioner fr tabell';
$strCookiesRequired = 'Kakor (cookies) mste tilltas fr att g vidare.';
$strCopy = 'Kopiera';
$strCopyDatabaseOK = 'Databas %s har kopierats till %s';
$strCopyTable = 'Kopiera tabellen till (databas<b>.</b>tabell):';
$strCopyTableOK = 'Tabellen %s har kopierats till %s.';
$strCopyTableSameNames = 'Kan inte kopiera tabell till samma namn!';
$strCouldNotKill = 'phpMyAdmin kunde inte dda trd %s. Troligtvis har den redan avslutats.';
$strCreate = 'Skapa';
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE fre kopiering';
$strCreateIndex = 'Skapa ett index fr&nbsp;%s&nbsp;kolumn(er)';
$strCreateIndexTopic = 'Skapa ett nytt index';
$strCreateNewDatabase = 'Skapa ny databas';
$strCreateNewTable = 'Skapa ny tabell i databas %s';
$strCreatePage = 'Skapa en ny sida';
$strCreatePdfFeat = 'Skapande av PDF-sidor';
$strCreationDates = 'Skapad/Uppdaterad/Kontrollerad datum';
$strCriteria = 'Villkor';
$strCroatian = 'Kroatisk';
$strCyrillic = 'Kyrillisk';
$strCzech = 'Tjeckisk';
$strCzechSlovak = 'Tjeckisk-Slovakisk';

$strDBComment = 'Databaskommentar: ';
$strDBCopy = 'Kopiera databas till';
$strDBGContext = 'Innehll';
$strDBGContextID = 'Innehlls-ID';
$strDBGHits = 'Trffar';
$strDBGLine = 'Rad';
$strDBGMaxTimeMs = 'Max tid, ms';
$strDBGMinTimeMs = 'Min tid, ms';
$strDBGModule = 'Modul';
$strDBGTimePerHitMs = 'Tid/trff, ms';
$strDBGTotalTimeMs = 'Total tid, ms';
$strDBRename = 'Dp om databasen till';
$strDanish = 'Dansk';
$strData = 'Data';
$strDataDict = 'Datalexikon';
$strDataOnly = 'Enbart data';
$strDataPages = 'Sidor innehllande data';
$strDatabase = 'Databas';
$strDatabaseEmpty = 'Databasens namn r tomt!';
$strDatabaseExportOptions = 'Exportalternativ fr databas';
$strDatabaseHasBeenDropped = 'Databasen %s har tagits bort.';
$strDatabaseNoTable = 'Denna databas innehller ingen tabell!';
$strDatabases = 'Databaser';
$strDatabasesDropped = '%s databaser har tagits bort.';
$strDatabasesStats = 'Databas-statistik';
$strDatabasesStatsDisable = 'Stng av statistik';
$strDatabasesStatsEnable = 'Sl p statistik';
$strDatabasesStatsHeavyTraffic = 'Anm: Att sl p databastatistik hr kan orsaka tung trafik mellan webb- och MySQL-servern.';
$strDbPrivileges = 'Databasspecifika privilegier';
$strDbSpecific = 'databasspecifik';
$strDefault = 'Standard';
$strDefaultEngine = '%s r standardlagringsmotorn p denna MySQL-server.';
$strDefaultValueHelp = 'Fr standardvrden, ange endast ett enstaka vrde, utan baktstreck eller citattecken, enligt formatet: a';
$strDefragment = 'Defragmentera tabell';
$strDelOld = 'Nuvarande sida har referenser till tabeller som inte lngre existerar. Vill du ta bort dessa referenser?';
$strDelayedInserts = 'Anvnd frdrjda infogningar';
$strDelete = 'Radera';
$strDeleteAndFlush = 'Ta bort anvndarna och ladda om privilegierna eftert.';
$strDeleteAndFlushDescr = 'Detta r det renaste sttet, men omladdning av privilegierna kan ta en stund.';
$strDeleted = 'Raden har raderats';
$strDeletedRows = 'Raderade rader';
$strDeleting = 'Tar bort %s';
$strDescending = 'Fallande';
$strDescription = 'Beskrivning';
$strDictionary = 'lexikon';
$strDirtyPages = 'Orena sidor';
$strDisableForeignChecks = 'Stng av kontroll av frmmande nycklar';
$strDisabled = 'Avaktiverat';
$strDisplayFeat = 'Visningsfunktionaliteter';
$strDisplayOrder = 'Visningsordning:';
$strDisplayPDF = 'Visa PDF-schema';
$strDoAQuery = 'Utfr en "Query By Example" (jokertecken: "%")';
$strDoYouReally = 'Vill du verkligen ';
$strDocu = 'Dokumentation';
$strDrop = 'Radera';
$strDropDatabaseStrongWarning = 'Du hller p att FRGRA en hel databas!';
$strDropSelectedDatabases = 'Ta bort markerade databaser';
$strDropUsersDb = 'Ta bort databaserna med samma namn som anvndarna.';
$strDumpSaved = 'SQL-satserna har sparats till filen %s.';
$strDumpXRows = 'Visa %s rader med brjan p rad %s.';
$strDumpingData = 'Data i tabell';
$strDynamic = 'dynamisk';

$strEdit = 'ndra';
$strEditPDFPages = 'Redigera PDF-sidor';
$strEditPrivileges = 'ndra privilegier';
$strEffective = 'Effektivt';
$strEmpty = 'Tm';
$strEmptyResultSet = 'MySQL skickade tillbaka ett tomt resultat (dvs inga rader).';
$strEnabled = 'Aktiverat';
$strEncloseInTransaction = 'Inneslut export i en transaktion';
$strEnd = 'Slutet';
$strEndCut = 'SLUT URKLIPP';
$strEndRaw = 'SLUT RTEXT';
$strEngineAvailable = '%s r tillgnglig p denna MySQL-server.';
$strEngineDisabled = '%s har stngts av p denna MySQL-server.';
$strEngineUnsupported = 'Denna MySQL-server har inte std fr lagringsmotorn %s.';
$strEngines = 'Motorer';
$strEnglish = 'Engelsk';
$strEnglishPrivileges = ' Obs! MySQL-privilegiumnamn anges p engelska ';
$strError = 'Fel';
$strEscapeWildcards = 'Jokerteknen _ och % mste fregs av ett \ fr att anvndas i egentlig betydelse';
$strEstonian = 'Estnisk';
$strExcelEdition = 'Excel-version';
$strExcelOptions = 'Excel-alternativ';
$strExecuteBookmarked = 'Utfr bokmrkt frga';
$strExplain = 'Frklara SQL-kod';
$strExport = 'Exportera';
$strExtendedInserts = 'Utkade infogningar';
$strExtra = 'Extra';

$strFailedAttempts = 'Misslyckade frsk';
$strField = 'Flt';
$strFieldHasBeenDropped = 'Fltet %s har tagits bort';
$strFields = 'Flt';
$strFieldsEmpty = ' Antalet flt r noll! ';
$strFieldsEnclosedBy = 'Flten omges av';
$strFieldsEscapedBy = 'Specialtecken i flt fregs av';
$strFieldsTerminatedBy = 'Flten avslutas med';
$strFileAlreadyExists = 'Filen %s finns redan p servern. ndra filnamnet eller kryssa i skriv ver-alternativet.';
$strFileCouldNotBeRead = 'Filen kunde inte lsas';
$strFileNameTemplate = 'Mall fr filnamn';
$strFileNameTemplateHelp = 'Anvnd __DB__ fr databasnamn, __TABLE__ fr tabellnamn och %sstrftime%s-alternativ fr specificering av tid. Filndelse lggs till automagiskt. All annan text kommer att bevaras.';
$strFileNameTemplateRemember = 'kom ihg mall';
$strFixed = 'fast';
$strFlushPrivilegesNote = 'Anm: phpMyAdmin hmtar anvndarnas privilegier direkt frn MySQL:s privilegiumtabeller. Innehllet i dessa tabeller kan skilja sig frn privilegierna som servern anvnder ifall manuella ndringar har gjorts. I detta fall br du %sladda om privilegierna%s innan du fortstter.';
$strFlushTable = 'Rensa tabell';
$strFormEmpty = 'Vrde saknas i formulret!';
$strFormat = 'Format';
$strFreePages = 'Fria sidor';
$strFullText = 'Fullstndiga texter';
$strFunction = 'Funktion';

$strGenBy = 'Genererad av';
$strGenTime = 'Skapad';
$strGeneralRelationFeat = 'Allmnna relationsfunktionaliteter';
$strGenerate = 'Generera';
$strGeneratePassword = 'Generera lsenord';
$strGeorgian = 'Georgisk';
$strGerman = 'Tysk';
$strGlobal = 'global';
$strGlobalPrivileges = 'Globala privilegier';
$strGlobalValue = 'Globalt vrde';
$strGo = 'Kr';
$strGrantOption = 'Grant';
$strGreek = 'Grekisk';
$strGzip = '"gzippad"';

$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Microsoft Excel 2000 exportalternativ';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Microsoft Word 2000 exportalternativ';
$strHasBeenAltered = 'har ndrats.';
$strHasBeenCreated = 'har skapats.';
$strHaveToShow = 'Du mste vlja minst en kolumn som ska visas';
$strHebrew = 'Hebreisk';
$strHexForBinary = 'Anvnd hexadecimalt fr binra flt';
$strHome = 'Hem';
$strHomepageOfficial = 'phpMyAdmin:s officiella hemsida';
$strHost = 'Vrd';
$strHostEmpty = 'Vrdnamnet r tomt!';
$strHungarian = 'Ungersk';

$strIcelandic = 'Islndska';
$strId = 'ID';
$strIdxFulltext = 'Heltext';
$strIfYouWish = 'Om du vill ladda enbart ngra av tabellens kolumner, ange en kommaseparerad fltlista.';
$strIgnore = 'Ignorera';
$strIgnoreInserts = 'Anvnd IGNORE i infogningar';
$strIgnoringFile = 'Ignorerar fil %s';
$strImportDocSQL = 'Importera docSQL-filer';
$strImportFiles = 'Importera filer';
$strImportFinished = 'Importen avslutad';
$strInUse = 'anvnds';
$strIndex = 'Index';
$strIndexHasBeenDropped = 'Index %s har tagits bort';
$strIndexName = 'Indexnamn&nbsp;:';
$strIndexType = 'Indextyp&nbsp;:';
$strIndexWarningMultiple = 'Mer n en %s-nyckel skapades fr kolumn `%s`';
$strIndexWarningPrimary = 'PRIMARY- och INDEX-nycklar skall inte bda sttas fr kolumn `%s`';
$strIndexWarningTable = 'Problem med index fr tabell `%s`';
$strIndexWarningUnique = 'UNIQUE- och INDEX-nycklar skall inte bda sttas fr kolumn `%s`';
$strIndexes = 'Index';
$strInnoDBAutoextendIncrement = 'Automatisk utkningsstorlek';
$strInnoDBAutoextendIncrementDesc = 'Tillkningsstorleken vid automatisk utkning av tabellutrymme nr det blir fullt.';
$strInnoDBBufferPoolSize = 'Buffertstorlek';
$strInnoDBBufferPoolSizeDesc = 'Storleken p minnesbufferten som InnoDB anvnder fr cache av data och index till sina tabeller.';
$strInnoDBDataFilePath = 'Datafiler';
$strInnoDBDataHomeDir = 'Hemkatalog fr data';
$strInnoDBDataHomeDirDesc = 'Den gemensamma delen av skvgen fr alla InnoDB-datafiler.';
$strInnoDBPages = 'sidor';
$strInnodbStat = 'InnoDB-status';
$strInsecureMySQL = 'Din konfigurationsfil innehller instllningar (root-konto utan lsenord) som motsvarar MySQL:s privilegierade standardkonto. Din MySQL-server krs med denna standardinstllning och r ppen fr intrng, s du br verkligen tppa till detta skerhetshl.';
$strInsert = 'Lgg till';
$strInsertAsNewRow = 'Lgg till som ny rad';
$strInsertBookmarkTitle = 'Var god ange bokmrkets namn';
$strInsertNewRow = 'Lgg till ny rad';
$strInsertTextfiles = 'Importera data frn textfil till tabellen';
$strInsertedRowId = 'Tillagd rads id:';
$strInsertedRows = 'Tillagda rader:';
$strInstructions = 'Instruktioner';
$strInternalNotNecessary = '* En intern relation r inte ndvndig nr den ven finns i InnoDB.';
$strInternalRelations = 'Interna relationer';

$strJapanese = 'Japansk';
$strJumpToDB = 'Hoppa till databas &quot;%s&quot;.';
$strJustDelete = 'Ta endast bort anvndarna frn privilegiumtabellerna.';
$strJustDeleteDescr = 'De &quot;borttagna&quot; anvndarna kommer fortfarande kunna komma t servern som vanligt tills privilegierna laddas om.';

$strKeepPass = 'ndra inte lsenordet';
$strKeyname = 'Nyckel';;
$strKill = 'Dda';
$strKorean = 'Koreansk';

$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX-alternativ';
$strLandscape = 'Liggande';
$strLatchedPages = 'Lsta sidor';
$strLatexCaption = 'Tabellrubrik';
$strLatexContent = 'Innehll i tabell __TABLE__';
$strLatexContinued = '(fortsttning)';
$strLatexContinuedCaption = 'Fortsatt tabellrubrik';
$strLatexIncludeCaption = 'Inkludera tabellrubrik';
$strLatexLabel = 'Etikett';
$strLatexStructure = 'Struktur fr tabell __TABLE__';
$strLatvian = 'Lettiska';
$strLengthSet = 'Lngd/Vrden*';
$strLimitNumRows = 'Rader per sida';
$strLineFeed = 'Radframmatning: \\n';
$strLinesTerminatedBy = 'Raderna avslutas med';
$strLinkNotFound = 'Lnk ej funnen';
$strLinksTo = 'Lnkar till';
$strLithuanian = 'Litauisk';
$strLoadExplanation = 'Den bsta metoden r frvald, men du kan byta om den inte fungerar.';
$strLoadMethod = 'LOAD-metod';
$strLocalhost = 'Lokal';
$strLocationTextfile = 'Textfilens plats';
$strLogPassword = 'Lsenord:';
$strLogServer = 'Server';
$strLogUsername = 'Anvndarnamn:';
$strLogin = 'Logga in';
$strLoginInformation = 'Inloggningsinformation';
$strLogout = 'Logga ut';
$strLongOperation = 'Denna operation kan ta lng tid. Frstt nd?';

$strMIMETypesForTable = 'MIME-TYPER FR TABELL';
$strMIME_MIMEtype = 'MIME-typ';
$strMIME_available_mime = 'Tillgngliga MIME-typer';
$strMIME_available_transform = 'Tillgngliga omvandlingar';
$strMIME_description = 'Beskrivning';
$strMIME_nodescription = 'Ingen beskrivning fr denna omvandling finns tillgnglig.<br />Vnligen frga upphovsmannen vad %s gr.';
$strMIME_transformation = 'Webblsaromvandling';
$strMIME_transformation_note = 'Fr en lista med tillgngliga omvandlingsparametrar och deras MIME-typomvandlingar, klicka p %somvandlingsbeskrivningar%s';
$strMIME_transformation_options = 'Omvandlingsparametrar';
$strMIME_transformation_options_note = 'Ange vrdena fr omvandlingsparametrar enligt fljande format: \'a\',\'b\',\'c\'...<br />Om du behver lgga till ett baktstreck ("\") eller ett enkelcitat ("\'") i vrdena, skriv ett baktstreck fre tecknet (t.ex. \'\\\\xyz\' eller \'a\\\'b\').';
$strMIME_without = 'Kursiverade MIME-typer har inte ngon separat omvandlingsfunktion';
$strMaximumSize = 'Maximal storlek: %s%s';
$strMbExtensionMissing = 'PHP-tillgget mbstring kunde inte hittas och det verkar som om du anvnder flerbitars teckenuppsttning. phpMyAdmin kan inte dela upp strngar korrekt utan tillgget mbstring, vilket kan leda till ovntade resultat.';
$strMbOverloadWarning = 'Du har aktiverat mbstring.func_overload i din PHP-konfiguration. Detta alternativ r inkompatibelt med phpMyAdmin och kan orsaka att en del data frstrs!';
$strModifications = 'ndringarna har sparats';
$strModify = 'ndra';
$strModifyIndexTopic = 'ndra ett index';
$strMoreStatusVars = 'Fler statusvariabler';
$strMoveTable = 'Flytta tabellen till (databas<b>.</b>tabell):';
$strMoveTableOK = 'Tabellen %s har flyttats till %s.';
$strMoveTableSameNames = 'Kan inte flytta tabell till samma namn!';
$strMultilingual = 'flersprkig';
$strMustSelectFile = 'Vlj filen som du vill importera.';
$strMyISAMDataPointerSize = 'Storlek fr datapekare';
$strMyISAMDataPointerSizeDesc = 'Standardpekarens storlek i bytes, vilken anvnds av CREATE TABLE fr MyISAM-tabeller nr inget MAX_ROWS-alternativ r specificerat.';
$strMyISAMMaxExtraSortFileSize = 'Maximal storlek fr temporra filer vid skapande av index';
$strMyISAMMaxExtraSortFileSizeDesc = 'Om den temporra filen som anvnds fr snabbt skapande av MyISAM-index skulle vara strre n att anvnda nyckelcachen vars storlek specificeras hr, s fredras metoden med nyckelcachen.';
$strMyISAMMaxSortFileSize = 'Maximal storlek fr temporra sorteringsfiler';
$strMyISAMMaxSortFileSizeDesc = 'Denna maximala storleken fr den temporra filen som MySQL r tillten att anvnda under terskapande av MyISAM-index (vid REPAIR TABLE, ALTER TABLE, eller LOAD DATA INFILE).';
$strMyISAMRecoverOptions = 'Automatisk terstllning';
$strMyISAMRecoverOptionsDesc = 'Instllningen fr automatisk terstllning av kraschade MyISAM-tabeller, som satts via serverns startparameter --myisam-recover.';
$strMyISAMRepairThreads = 'Reparera trdar';
$strMyISAMRepairThreadsDesc = 'Om detta vrde r strre n 1 skapas MyISAM-tabellindex parallellt (varje index i sin egen trd) under reparationen vid sorteringsprocess.';
$strMyISAMSortBufferSize = 'Storlek fr sorteringsbuffert';
$strMyISAMSortBufferSizeDesc = 'Bufferten som allokeras vid sortering av MyISAM-index under REPAIR TABLE eller vid skapande av index med CREATE INDEX eller ALTER TABLE.';
$strMySQLCharset = 'MySQL teckenuppsttning';
$strMySQLConnectionCollation = 'Kollation fr MySQL-uppkoppling';
$strMySQLReloaded = 'MySQL har startats om.';
$strMySQLSaid = 'MySQL sa: ';
$strMySQLServerProcess = 'MySQL %pma_s1% krs p %pma_s2% som %pma_s3%';
$strMySQLShowProcess = 'Visa processer';
$strMySQLShowStatus = 'Visa MySQL-krningsinformation';
$strMySQLShowVars = 'Visa MySQL:s systemvariabler';

$strName = 'Namn';
$strNeedPrimaryKey = 'Du br definiera en primrnyckel fr denna tabell.';
$strNext = 'Nsta';
$strNo = 'Nej';
$strNoActivity = 'Ingen aktivitet sedan %s sekunder eller mer. Var god logga in igen';
$strNoDatabases = 'Inga databaser';
$strNoDatabasesSelected = 'Inga databaser markerade.';
$strNoDescription = 'Ingen beskrivning';
$strNoDetailsForEngine = 'Det finns ingen tillgnglig detaljerad statusinformation fr denna lagringsmotor.';
$strNoDropDatabases = '"DROP DATABASE"-instruktioner r avstngda.';
$strNoExplain = 'Utan SQL-frklaring';
$strNoFrames = 'phpMyAdmin fungerar tyvrr endast med webblsare som hanterar ramar.';
$strNoIndex = 'Inga index r definierade!';
$strNoIndexPartsDefined = 'Inga delar av index r definierade!';
$strNoModification = 'Ingen frndring';
$strNoOptions = 'Detta format har inga alternativ';
$strNoPassword = 'Inget lsenord';
$strNoPermission = 'Webbservern har inte tilltelse att spara filen %s.';
$strNoPhp = 'Utan PHP-kod';
$strNoPrivileges = 'Inga privilegier';
$strNoQuery = 'Ingen SQL-frga!';
$strNoRights = 'Du har inte tillrcklig behrighet fr att vara hr nu!';
$strNoRowsSelected = 'Inga rader valda';
$strNoSpace = 'Otillrckligt utrymme fr att spara filen %s.';
$strNoTablesFound = 'Inga tabeller funna i databasen.';
$strNoThemeSupport = 'Std fr teman saknas. Kontrollera din konfiguration och/eller dina teman i katalog %s.';
$strNoUsersFound = 'Hittade ingen anvndare.';
$strNoValidateSQL = 'Utan SQL-validering';
$strNone = 'Inget';
$strNotNumber = 'Det r inte ett nummer!';
$strNotOK = 'Inte OK';
$strNotSet = '<b>%s</b>-tabellen ej funnen eller ej angiven i %s';
$strNotValidNumber = ' r inte ett giltigt radnummer!';
$strNull = 'Null';
$strNumSearchResultsInTable = '%s trff(ar) i tabell <i>%s</i>';
$strNumSearchResultsTotal = '<b>Totalt:</b> <i>%s</i> trff(ar)';
$strNumTables = 'Tabeller';
$strNumberOfFields = 'Antal flt';

$strOK = 'OK';
$strOftenQuotation = 'Ofta citattecken. Frivilligt innebr att bara flt av typ \'char\' och \'varchar\' omges av angivet tecken.';
$strOperations = 'Operationer';
$strOperator = 'Operator';
$strOptimizeTable = 'Optimera tabell';
$strOptionalControls = 'Frivilligt. Styr hur lsning och skrivning av specialtecken utfrs.';
$strOptionally = 'Frivilligt';
$strOr = 'Eller';
$strOverhead = 'Outnyttjat';
$strOverwriteExisting = 'Skriv ver befintlig fil(er)';

$strPHP40203 = 'Du anvnder PHP 4.2.3, vilken har en allvarlig bugg med multi-byte-strngar (mbstring). Se PHP:s buggrapport 19404. Denna version av PHP r inte rekommenderad fr anvndning tillsammans med phpMyAdmin.';
$strPHPVersion = 'PHP-version';
$strPageNumber = 'Sida:';
$strPagesToBeFlushed = 'Sidor att rensa';
$strPaperSize = 'Pappersstorlek';
$strPartialText = 'Avkortade texter';
$strPassword = 'Lsenord';
$strPasswordChanged = 'Lsenordet fr %s har ndrats.';
$strPasswordEmpty = 'Lsenordet r tomt!';
$strPasswordHashing = 'Hashning av lsenord';
$strPasswordNotSame = 'Lsenorden r inte lika!';
$strPdfDbSchema = 'Schema fr databasen "%s" - Sidan %s';
$strPdfInvalidTblName = 'Tabellen "%s" finns inte!';
$strPdfNoTables = 'Inga tabeller';
$strPerHour = 'per timme';
$strPerMinute = 'per minut';
$strPerSecond = 'per sekund';
$strPersian = 'Persiska';
$strPhoneBook = 'telefonbok';
$strPhp = 'Skapa PHP-kod';
$strPmaDocumentation = 'phpMyAdmin dokumentation';
$strPmaUriError = 'Variabeln <tt>$cfg[\'PmaAbsoluteUri\']</tt> MSTE anges i din konfigurationsfil!';
$strPolish = 'Polska';
$strPortrait = 'Stende';
$strPos1 = 'Brjan';
$strPrevious = 'Fregende';
$strPrimary = 'Primr';
$strPrimaryKeyHasBeenDropped = 'Den primra nyckeln har tagits bort';
$strPrimaryKeyName = 'Primrnyckelns namn mste vara "PRIMARY"!';
$strPrimaryKeyWarning = '("PRIMARY" <b>mste</b> vara namnet p och <b>endast p</b> en primrnyckel!)';
$strPrint = 'Skriv ut';
$strPrintView = 'Utskriftsvnlig visning';
$strPrintViewFull = 'Utskriftsvnlig visning (med fullstndiga texter)';
$strPrivDescAllPrivileges = 'Inkluderar alla privilegier utom GRANT.';
$strPrivDescAlter = 'Tillter ndring av befintliga tabellers struktur.';
$strPrivDescAlterDb = 'Tillter ndring av befintliga tabellers struktur svl som ndring av standardteckenuppsttningen och kollationering av databaser.';
$strPrivDescAlterRoutine = 'Tillter ndring och borttagning av lagrade rutiner.';
$strPrivDescCreateDb = 'Tillter skapande av nya databaser och tabeller.';
$strPrivDescCreateRoutine = 'Tillter skapande av lagrade rutiner.';
$strPrivDescCreateTbl = 'Tillter skapande av nya tabeller.';
$strPrivDescCreateTmpTable = 'Tillter skapande av temporra tabeller.';
$strPrivDescCreateUser = 'Tillter skapande, borttagning och omdpning av anvndarkonton.';
$strPrivDescCreateView = 'Tillter skapande av nya vyer.';
$strPrivDescDelete = 'Tillter borttagning av data.';
$strPrivDescDropDb = 'Tillter borttagning av databaser och tabeller.';
$strPrivDescDropTbl = 'Tillter borttagning av tabeller.';
$strPrivDescExecute = 'Tillter krning av lagrade procedurer; Har ingen verkan i denna MySQL-version.';
$strPrivDescExecute5 = 'Tillter utfrande av lagrade rutiner.';
$strPrivDescFile = 'Tillter import av data frn och export av data till filer.';
$strPrivDescGrant = 'Tillter tillgg av anvndare och privilegier utan omladdning av privilegiumtabellerna.';
$strPrivDescIndex = 'Tillter skapande och borttagning av index.';
$strPrivDescInsert = 'Tillter infogning och ersttning av data.';
$strPrivDescLockTables = 'Tillter lsning av tabeller fr gllande trd.';
$strPrivDescMaxConnections = 'Begrnsar antalet nya frbindelser anvndaren kan ppna per timme.';
$strPrivDescMaxQuestions = 'Begrnsar antalet frgor anvndaren kan skicka till servern per timme.';
$strPrivDescMaxUpdates = 'Begrnsar antalet kommandon, vilka ndrar ngon tabell eller databas, som anvndaren kan utfra per timme.';
$strPrivDescProcess3 = 'Tillter ddande av andra anvndares processer.';
$strPrivDescProcess4 = 'Tillter visning av fullstndiga frgor i processlistan.';
$strPrivDescReferences = 'Har ingen verkan i denna MySQL-version.';
$strPrivDescReload = 'Tillter omladdning av serverinstllningar och rensning av serverns cache.';
$strPrivDescReplClient = 'Ger anvndaren rtt att frga var slav- / huvudservrarna r.';
$strPrivDescReplSlave = 'Ndvndig fr replikationsslavar.';
$strPrivDescSelect = 'Tillter lsning av data.';
$strPrivDescShowDb = 'Ger tillgng till den fullstndiga databaslistan.';
$strPrivDescShowView = 'Tillter utfrande av SHOW CREATE VIEW-frgor.';
$strPrivDescShutdown = 'Tillter avstngning av servern.';
$strPrivDescSuper = 'Tillter uppkoppling, ven om maximala antalet frbindelser r ndd. Ndvndig fr de flesta administrativa funktioner, som att stta globala variabler eller dda andra anvndares trdar.';
$strPrivDescUpdate = 'Tillter ndring av data.';
$strPrivDescUsage = 'Inga privilegier.';
$strPrivileges = 'Privilegier';
$strPrivilegesReloaded = 'Privilegierna har laddats om.';
$strProcesslist = 'Processlista';
$strPutColNames = 'Ange fltnamn p frsta raden';

$strQBE = 'Skapa frga';
$strQBEDel = 'Ta bort';
$strQBEIns = 'Infoga';
$strQueryFrame = 'Frgefnster';
$strQueryOnDb = 'SQL-frga i databas <b>%s</b>:';
$strQuerySQLHistory = 'SQL-historik';
$strQueryStatistics = '<b>Frgestatistik</b>: %s frgor har skickats till servern sedan den startade.';
$strQueryTime = 'Frgan tog %01.4f sek';
$strQueryType = 'Typ av frga';
$strQueryWindowLock = 'Skriv inte ver denna frga utifrn detta fnster';

$strReType = 'Skriv igen';
$strReadRequests = 'Lsbegranden';
$strReceived = 'Mottagna';
$strRecords = 'Rader';
$strReferentialIntegrity = 'Kontrollera referensintegritet:';
$strRefresh = 'Uppdatera';
$strRelationNotWorking = 'Den extra funktionaliteten fr att hantera lnkade tabeller har avaktiverats. %sVisa orsaken%s.';
$strRelationView = 'Visa relationer';
$strRelationalSchema = 'Relationsschema';
$strRelations = 'Relationer';
$strRelationsForTable = 'RELATIONER FR TABELL';
$strReloadFailed = 'Omladdning av MySQL misslyckades.';
$strReloadMySQL = 'Ladda om MySQL';
$strReloadingThePrivileges = 'Laddar om privilegierna';
$strRemoveSelectedUsers = 'Ta bort markerade anvndare';
$strRenameDatabaseOK = 'Databas %s har dpts om till %s';
$strRenameTable = 'Dp om tabellen till';
$strRenameTableOK = 'Tabell %s har dpts om till %s';
$strRepairTable = 'Reparera tabell';
$strReplace = 'Erstt';
$strReplaceNULLBy = 'Erstt NULL med';
$strReplaceTable = 'Erstt data i tabell';
$strReset = 'Nollstll';
$strResourceLimits = 'Resursbegrnsningar';
$strRevoke = 'Upphv';
$strRevokeAndDelete = 'Upphv anvndarnas alla aktiva privilegier och ta bort anvndarna eftert.';
$strRevokeAndDeleteDescr = 'Anvndarna kommer fortfarande ha kvar privilegiet USAGE tills privilegierna laddas om.';
$strRevokeMessage = 'Du har upphvt privilegierna fr %s';
$strRomanian = 'Rumnska';
$strRoutines = 'Rutiner';
$strRowLength = 'Radlngd';
$strRowSize = 'Radstorlek';
$strRows = 'Rader';
$strRowsFrom = 'rader med brjan frn';
$strRowsModeFlippedHorizontal = 'vgrtt (roterade rubriker)';
$strRowsModeHorizontal = 'vgrtt';
$strRowsModeOptions = 'i %s format och upprepa rubrikerna efter %s celler';
$strRowsModeVertical = 'lodrtt';
$strRowsStatistic = 'Radstatistik';
$strRunQuery = 'Kr frga';
$strRunSQLQuery = 'Kr SQL-frga/frgor i databasen %s';
$strRunning = 'krs p %s';
$strRussian = 'Rysk';

$strSQL = 'SQL';
$strSQLExportCompatibility = 'SQL-export-kompatibilitet';
$strSQLExportType = 'Export-typ';
$strSQLOptions = 'SQL-alternativ';
$strSQLParserBugMessage = 'Det r mjligt att du har hittat en bugg i SQL-analysatorn. Var god granska din frga noga och kontrollera att citationstecknen r korrekta och matchar varandra. En annan mjlig felorsak kan vara att du verfr en fil med binrkod som inte ligger inom citationstecken. Du kan ven testa din frga i MySQL:s kommandoradsgrnssnitt. Felmeddelandet frn MySQL-servern nedan, om det finns ngot, kan ocks hjlpa dig att analysera problemet. Om du fortfarande har problem eller om SQL-analysatorn misslyckas nr kommandoradsgrnssnittet lyckas, var vnlig reducera din inmatning av SQL-frgor till den enda frga som orsakar problem och skicka en buggrapport med datastycket i URKLIPP-sektionen nedan:';
$strSQLParserUserError = 'Det verkar vara ett fel i din SQL-frga. Felmeddelandet frn MySQL-servern nedan, om det finns ngot, kan ocks hjlpa dig att analysera problemet.';
$strSQLQuery = 'SQL-frga';
$strSQLResult = 'SQL-resultat';
$strSQPBugInvalidIdentifer = 'Ogiltig identifierare';
$strSQPBugUnclosedQuote = 'Oavslutat citat';
$strSQPBugUnknownPunctuation = 'Oknd interpunktion i strng';
$strSave = 'Spara';
$strSaveOnServer = 'Spara p servern i katalogen %s';
$strScaleFactorSmall = 'Skalfaktorn r fr liten fr att schemat ska f plats p en sida';
$strSearch = 'Sk';
$strSearchFormTitle = 'Sk i databas';
$strSearchInTables = 'I tabell(er):';
$strSearchNeedle = 'Ord eller vrde(n) att ska efter (jokertecken: "%"):';
$strSearchOption1 = 'minst ett av orden';
$strSearchOption2 = 'alla ord';
$strSearchOption3 = 'den exakta frasen';
$strSearchOption4 = 'som reguljrt uttryck';
$strSearchResultsFor = 'Resultat av skning efter "<i>%s</i>" %s:';
$strSearchType = 'Hitta:';
$strSecretRequired = 'Konfigurationsfilen behver nu ett hemligt lsenord (blowfish_secret).';
$strSelectADb = 'Vlj en databas';
$strSelectAll = 'Markera alla';
$strSelectBinaryLog = 'Vlj binr logg att visa';
$strSelectFields = 'Vlj flt (minst ett):';
$strSelectNumRows = 'i frga';
$strSelectTables = 'Vlj tabeller';
$strSend = 'Spara som fil';
$strSent = 'Skickade';
$strServer = 'Server';
$strServerChoice = 'Serverval';
$strServerNotResponding = 'Servern svarar inte';
$strServerStatus = 'Krningsinformation';
$strServerStatusUptime = 'Denna MySQL-server har krts i %s. Den startade den %s.';
$strServerTabProcesslist = 'Processer';
$strServerTabVariables = 'Variabler';
$strServerTrafficNotes = '<b>Servertrafik</b>: Dessa tabeller visar statistik fr ntverkstrafiken hos denna MySQL-server sedan den startade.';
$strServerVars = 'Servervariabler och instllningar';
$strServerVersion = 'Serverversion';
$strSessionValue = 'Sessionsvrde';
$strSetEnumVal = 'Om en flttyp r "enum" eller "set", ange vrden enligt fljande format: \'a\',\'b\',\'c\'...<br />Om du behver lgga till ett baktstreck ("\") eller ett enkelcitat ("\'") i vrdena, skriv ett baktstreck fre tecknet (t.ex. \'\\\\xyz\' eller \'a\\\'b\').';
$strShow = 'Visa';
$strShowAll = 'Visa alla';
$strShowColor = 'Visa frger';
$strShowDatadictAs = 'Format fr datalexikon';
$strShowFullQueries = 'Visa fullstndiga frgor';
$strShowGrid = 'Visa rutnt';
$strShowPHPInfo = 'Visa PHP-information';
$strShowTableDimension = 'Visa tabellers dimensioner';
$strShowTables = 'Visa tabeller';
$strShowThisQuery = ' Visa frgan hr igen ';
$strShowingRecords = 'Visar rader ';
$strSimplifiedChinese = 'Frenklad kinesiska';
$strSingly = '(ensam)';
$strSize = 'Storlek';
$strSlovak = 'Slovakiska';
$strSlovenian = 'Slovenska';
$strSocketProblem = '(eller den lokala MySQL-serverns socket r inte korrekt konfigurerad)';
$strSort = 'Sortering';
$strSortByKey = 'Sortera efter nyckel';
$strSpaceUsage = 'Utrymmesanvndning';
$strSpanish = 'Spanska';
$strSplitWordsWithSpace = 'Ord separeras med mellanslag (" ").';
$strStatCheckTime = 'Senaste kontroll';
$strStatCreateTime = 'Skapades';
$strStatUpdateTime = 'Senaste uppdatering';
$strStatement = 'Uppgift';
$strStatus = 'Status';
$strStorageEngine = 'Lagringsmotor';
$strStorageEngines = 'Lagringsmotorer';
$strStrucCSV = 'CSV';
$strStrucData = 'Struktur och data';
$strStrucDrop = 'Lgg till DROP TABLE';
$strStrucExcelCSV = 'CSV fr MS Excel';
$strStrucNativeExcel = 'Naturlig MS Excel-data';
$strStrucOnly = 'Enbart struktur';
$strStructPropose = 'Fresl tabellstruktur';
$strStructure = 'Struktur';
$strSubmit = 'Snd';
$strSuccess = 'Din SQL-frga utfrdes korrekt';
$strSum = 'Summa';
$strSwedish = 'Svensk';
$strSwitchToDatabase = 'Byt till kopierad databas';
$strSwitchToTable = 'Byt till kopierad tabell';

$strTable = 'Tabell';
$strTableComments = 'Tabellkommentarer';
$strTableEmpty = 'Tabellnamnet r tomt!';
$strTableHasBeenDropped = 'Tabellen %s har tagits bort';
$strTableHasBeenEmptied = 'Tabellen %s har tmts';
$strTableHasBeenFlushed = 'Tabellen %s har rensats';
$strTableMaintenance = 'Tabellunderhll';
$strTableOfContents = 'Innehllsfrteckning';
$strTableOptions = 'Tabellalternativ';
$strTableStructure = 'Struktur fr tabell';
$strTableType = 'Tabelltyp';
$strTables = '%s tabell(er)';
$strTakeIt = 'anvnd detta';
$strTblPrivileges = 'Tabellspecifika privilegier';
$strTextAreaLength = ' P grund av dess lngd,<br /> kanske detta flt inte kan redigeras ';
$strThai = 'Thailndsk';
$strTheContent = 'Filens innehll har importerats.';
$strTheContents = 'Filens innehll erstter den valda tabellens rader som har identiska primra eller unika nycklar.';
$strTheTerminator = 'Fltavslutare.';
$strTheme = 'Tema / Stil';
$strThisHost = 'Denna vrd';
$strThisNotDirectory = 'Detta var inte en katalog';
$strThreadSuccessfullyKilled = 'Trd %s ddades med framgng.';
$strTime = 'Tid';
$strToggleScratchboard = 'Visa/dlj skisstavla';
$strTotal = 'totalt';
$strTotalUC = 'Totalt';
$strTraditionalChinese = 'Traditionell kinesiska';
$strTraditionalSpanish = 'Traditionell Spanska';
$strTraffic = 'Trafik';
$strTransformation_application_octetstream__download = 'Visar en lnk fr att ladda ner fltets binra data. Du kan anvnda frsta parametern fr att ange filnamnet eller anvnda den andra parametern fr att ange fltnamnet fr en tabellkolumn som innehller filnamn. Om du anger andra parametern s mste frsta parametern sttas till en tom strng.';
$strTransformation_application_octetstream__hex = 'Visar hexadecimal representation av data.';
$strTransformation_image_jpeg__inline = 'Visar en klickbar tumnagelbild. Parametrarna r maximal bredd och hjd i pixlar. Bildens ursprungliga proportioner bibehlls.';
$strTransformation_image_jpeg__link = 'Visar en lnk fr att ladda ner denna bild.';
$strTransformation_image_png__inline = 'Se image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Visar ett TIME, TIMESTAMP eller DATETIME-flt enligt ditt lokala datum-/tidsformat. Frsta parametern r frskjutningen (i timmar) som kommer att lggas till tidsstmpeln (standardvrde: 0). Anvnd andra parametern fr att ange ett annat datum-/tidsformat; se dokumentationen fr PHP:s funktion strftime().';
$strTransformation_text_plain__external = 'ENDAST LINUX: Startar en extern applikation och skickar fltdata till den via standard-indata. Returnerar applikationens standard-utdata. Standard r Tidy, fr att snygga till HTML-kod. Av skerhetsskl mste du manuellt redigera filen libraries/transformations/text_plain__external.inc.php och infoga verktygen du vill tillta ska f kras. Den frsta parametern r d numret fr det program som du vill anvnda och den andra parametern r parametrarna fr programmet. Om den tredje parametern stts till 1 kommer utdata konverteras mha htmlspecialchars() (standardvrde: 1). Om den fjrde parametern stts till 1 kommer radbrytning att undvikas s att all utdata kommer att visas p en rad (standardvrde: 1).';
$strTransformation_text_plain__formatted = 'Visar innehllet i fltet som det r, utan att kra det genom htmlspecialchars(). Det innebr att fltet antas innehlla korrekt HTML-kod.';
$strTransformation_text_plain__imagelink = 'Visar en bild och en lnk; fltet innehller filnamnet. Frsta parametern r ett URL-prefix ssom "http://www.example.com/". Andra och tredje parametern r bredden och hjden i pixlar.';
$strTransformation_text_plain__link = 'Visar en lnk; fltet innehller filnamnet. Frsta parametern r ett URL-prefix ssom "http://www.example.com/". Andra parametern r en titel fr lnken.';
$strTransformation_text_plain__substr = 'Visar del av en strng. Frsta parametern r antalet tecken att hoppa ver frn brjan p strngen (standardvrde: 0). Andra parametern r antalet tecken som ska returneras (standardvrde: till slutet p strngen). Den tredje parametern r en strng som lggs till i slutet och/eller brjan nr trunkering utfrs (standardvrde: "...").';
$strTruncateQueries = 'Korta av visade frgor';
$strTurkish = 'Turkisk';
$strType = 'Typ';

$strUkrainian = 'Ukrainsk';
$strUncheckAll = 'Avmarkera alla';
$strUnicode = 'Unicode';
$strUnique = 'Unik';
$strUnknown = 'oknd';
$strUnselectAll = 'Avmarkera alla';
$strUpdComTab = 'Se dokumentationen fr uppdatering av din tabell column_comments';
$strUpdatePrivMessage = 'Du har uppdaterat privilegierna fr %s.';
$strUpdateProfileMessage = 'Profilen har uppdaterats.';
$strUpdateQuery = 'Uppdatera frga';
$strUpgrade = 'Du br uppgradera till %s %s eller senare.';
$strUsage = 'Anvndning';
$strUseBackquotes = 'Anvnd baktcitat runt tabell- och fltnamn';
$strUseHostTable = 'Anvnd vrdtabell';
$strUseTabKey = 'Anvnd TAB-tangenten fr att flytta frn vrde till vrde, eller CTRL+pil fr att flytta vart som helst';
$strUseTables = 'Anvnd tabeller';
$strUseTextField = 'Anvnd textfltet';
$strUseThisValue = 'Anvnd detta vrde';
$strUser = 'Anvndare';
$strUserAlreadyExists = 'Anvndaren %s finns redan!';
$strUserEmpty = 'Anvndarnamnet r tomt!';
$strUserName = 'Anvndarnamn';
$strUserNotFound = 'Den markerade anvndaren kunde inte hittas i privilegiumtabellen.';
$strUserOverview = 'Anvndarversikt';
$strUsersDeleted = 'De markerade anvndarna har tagits bort.';
$strUsersHavingAccessToDb = 'Anvndare som har tillgng till &quot;%s&quot;';

$strValidateSQL = 'Validera SQL-kod';
$strValidatorError = 'SQL-validatorn kunde inte initieras. Kontrollera om du har installerat de ndvndiga PHP-tillggen enligt %sdokumentationen%s.';
$strValue = 'Vrde';
$strVar = 'Variabel';
$strVersionInformation = 'Versionsinformation';
$strView = 'Vy';
$strViewDump = 'Visa SQL-satser fr tabellen';
$strViewDumpDB = 'Visa SQL-satser fr databasen';
$strViewDumpDatabases = 'Visa SQL-satser fr databaser';
$strViewHasBeenDropped = 'Vyn %s har tagits bort';

$strWebServerUploadDirectory = 'Uppladdningskatalog p webbserver';
$strWebServerUploadDirectoryError = 'Katalogen som du konfigurerat fr uppladdning kan inte ns';
$strWelcome = 'Vlkommen till %s';
$strWestEuropean = 'Vsteuropeisk';
$strWildcard = 'jokertecken';
$strWindowNotFound = 'Mlfnstret kunde inte uppdateras. Orsaken kan vara att du stngt frldrafnstret eller att din webblsares skerhetsinstllningar blockerar uppdateringar mellan fnster.';
$strWithChecked = 'Med markerade:';
$strWriteRequests = 'Skrivbegranden';
$strWritingCommentNotPossible = 'Skrivning av kommentar inte mjlig';
$strWritingRelationNotPossible = 'Skrivning av relation inte mjlig';
$strWrongUser = 'Fel anvndarnamn/lsenord. tkomst nekad.';

$strXML = 'XML';

$strYes = 'Ja';

$strZeroRemovesTheLimit = 'Anm: Genom att stta dessa alternativ till 0 (noll) tas begrnsningarna bort.';
$strZip = '"zippad"';

?>
